==> openshift-serverless-1-tech-preview-eventing-webhook-rhel8-container-0.13.0-3.tar.gz: openshift-serverless-1-tech-preview-eventing-webhook-rhel8-container-0.13.0-3/test/e2e/channel_single_event_test.go <==
// +build e2e

/*
Copyright 2019 The Knative Authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package e2e

import (
	"testing"

	cloudevents "github.com/cloudevents/sdk-go"

	"knative.dev/eventing/test/e2e/helpers"
)

/*
SingleEventForChannelTestHelper tests the following scenario:

EventSource ---> Channel ---> Subscription ---> Service(Logger)

*/

func TestSingleBinaryEventForChannel(t *testing.T) {
	helpers.SingleEventForChannelTestHelper(
		t,
		cloudevents.Binary,
		"v1alpha1",
		channelTestRunner,
	)
}

func TestSingleStructuredEventForChannel(t *testing.T) {
	helpers.SingleEventForChannelTestHelper(
		t,
		cloudevents.Structured,
		"v1alpha1",
		channelTestRunner,
	)
}

func TestSingleBinaryEventForChannelV1Beta1(t *testing.T) {
	helpers.SingleEventForChannelTestHelper(
		t,
		cloudevents.Binary,
		"v1beta1",
		channelTestRunner,
	)
}

func TestSingleStructuredEventForChannelV1Beta1(t *testing.T) {
	helpers.SingleEventForChannelTestHelper(
		t,
		cloudevents.Structured,
		"v1beta1",
		channelTestRunner,
	)
}

==> openshift-serverless-1-tech-preview-eventing-webhook-rhel8-container-0.16.0-8.tar.gz: openshift-serverless-1-tech-preview-eventing-webhook-rhel8-container-0.16.0-8/test/e2e/channel_single_event_test.go <==
// +build e2e

/*
Copyright 2019 The Knative Authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package e2e

import (
	"testing"

	cloudevents "github.com/cloudevents/sdk-go/v2"

	"knative.dev/eventing/test/e2e/helpers"
)

/*
SingleEventForChannelTestHelper tests the following scenario:

EventSource ---> Channel ---> Subscription ---> Service(Logger)

*/

func TestSingleBinaryEventForChannelV1Beta1(t *testing.T) {
	helpers.SingleEventForChannelTestHelper(
		t,
		cloudevents.EncodingBinary,
		helpers.SubscriptionV1beta1,
		"",
		channelTestRunner,
	)
}

func TestSingleStructuredEventForChannelV1Beta1(t *testing.T) {
	helpers.SingleEventForChannelTestHelper(
		t,
		cloudevents.EncodingStructured,
		helpers.SubscriptionV1beta1,
		"",
		channelTestRunner,
	)
}

func TestSingleBinaryEventForChannelV1(t *testing.T) {
	helpers.SingleEventForChannelTestHelper(
		t,
		cloudevents.EncodingBinary,
		helpers.SubscriptionV1,
		"",
		channelTestRunner,
	)
}

func TestSingleStructuredEventForChannelV1(t *testing.T) {
	helpers.SingleEventForChannelTestHelper(
		t,
		cloudevents.EncodingStructured,
		helpers.SubscriptionV1,
		"",
		channelTestRunner,
	)
}
